==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/flow-designer/ui/manage-remote-ports/manage-remote-ports.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { ManageRemotePorts } from './manage-remote-ports.component';
import { provideMockStore } from '@ngrx/store/testing';
import { RouterTestingModule } from '@angular/router/testing';
import { HttpClientTestingModule } from '@angular/common/http/testing';
import { initialState } from '../../state/manage-remote-ports/manage-remote-ports.reducer';
import { MockComponent } from 'ng-mocks';
import { Navigation } from '../../../../ui/common/navigation/navigation.component';
import { remotePortsFeatureKey } from '../../state/manage-remote-ports';

describe('ManageRemotePorts', () => {
    let component: ManageRemotePorts;
    let fixture: ComponentFixture<ManageRemotePorts>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            declarations: [ManageRemotePorts],
            imports: [RouterTestingModule, MockComponent(Navigation), HttpClientTestingModule],
            providers: [
                provideMockStore({
                    initialState: {
                        [remotePortsFeatureKey]: initialState
                    }
                })
            ]
        });
        fixture = TestBed.createComponent(ManageRemotePorts);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/flow-designer/ui/manage-remote-ports/manage-remote-ports.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { ManageRemotePorts } from './manage-remote-ports.component';
import { provideMockStore } from '@ngrx/store/testing';
import { RouterTestingModule } from '@angular/router/testing';
import { HttpClientTestingModule } from '@angular/common/http/testing';
import { initialState } from '../../state/manage-remote-ports/manage-remote-ports.reducer';
import { MockComponent } from 'ng-mocks';
import { Navigation } from '../../../../ui/common/navigation/navigation.component';
import { remotePortsFeatureKey } from '../../state/manage-remote-ports';
import { NgxSkeletonLoaderComponent } from 'ngx-skeleton-loader';

describe('ManageRemotePorts', () => {
    let component: ManageRemotePorts;
    let fixture: ComponentFixture<ManageRemotePorts>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            declarations: [ManageRemotePorts],
            imports: [
                RouterTestingModule,
                MockComponent(Navigation),
                HttpClientTestingModule,
                MockComponent(NgxSkeletonLoaderComponent)
            ],
            providers: [
                provideMockStore({
                    initialState: {
                        [remotePortsFeatureKey]: initialState
                    }
                })
            ]
        });
        fixture = TestBed.createComponent(ManageRemotePorts);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});
